
1. Update the implementation to reflect the new spec: 

<spec>
### CLI command `timestamp` (short synonym: `t`)

(`--input_path` and `--output_path` as previously)

Optional parameter

- `--separator`: string, defaults to ` tX` (space plus `tX`)
- `--replace_timestamp`: bool, defaults to True; if provided, then before adding the timestamp suffix, it removes the old timestamp suffix, given that it uses the default separator. In other words, from family name it removes ` tX` and everything after, and from family slug removes `tX` and everything after
</spec>

2. Fully rewrite @./README.md so that it very accurately and extensive reflects the implementation. Keep all the facts that exist there, but first describe installation ( https://pypi.org/project/fontnome/ ) and usage, the what and the why, and after that the detailed how (adapted and expanded from the current content). 

3. Fully /cleanup @TODO.md and @PLAN.md and @WORK.md: remove all tasks that are completed

4. Make @./CHANGELOG.md more compact

5. Make @./CLAUDE.md more consistent and streamlined but don’t remove anything

6. Then /work on any outstanding tasks from @TODO.md and @PLAN.md

